@@ -1,7 +1,9 @@
 #[allow(unused_imports)]
 #[allow(unused_macros)]
+
 #[macro_use]
-pub extern crate diesel;
+extern crate diesel;
+
 pub extern crate async_graphql;
 pub extern crate derive_more;
 pub extern crate diesel_derive_newtype;
@@ -14,7 +16,7 @@ macro_rules! derive_id {
 			$crate::async_graphql::NewType,
 			$crate::derive_more::Display,
 			$crate::diesel_derive_newtype::DieselNewType,
-			$crate::diesel::Identifiable,
+		  Identifiable,
 			$crate::serde::Deserialize,
 			$crate::serde::Serialize,
 			Clone,
